@@ -1,7 +1,8 @@
 import lxml.etree as ET
 from yankee.base import fields
+from yankee.util import clean_whitespace
 
-from .key import XmlMixin
+from .mixin import XmlMixin
 
 
 class Field(XmlMixin, fields.Field):
@@ -55,6 +56,17 @@ class Alternative(XmlMixin, fields.Alternative):
 class DelimitedString(XmlMixin, fields.DelimitedString):
     pass
 
+class Nested(XmlMixin, fields.Nested):
+    pass
+
+class TailField(fields.Field):
+    """Field to retreive tail text"""
+
+    def load(self, obj):
+        return super().load(obj)
+
+    def deserialize(self, obj):
+        return clean_whitespace(super().deserialize(obj).tail)
 
 # Aliases
 Str = String
